
---------------------------------------------------
-- [v1.01.00] Make sure we have nUI tables
---------------------------------------------------
if not nUI_InfoPanels then nUI_InfoPanels = {}; end

----------------------------------------------------------------
-- [v1.01.00] Localized Functions and Tables to speed things up
----------------------------------------------------------------
local _L = nUI_InfoPanel_PallyPower_L;

---------------------------------------------------
-- [v1.01.00] Allocation of the Window ID (unique)
---------------------------------------------------
nUI_INFOMODE_PALLYPOWER  = 20;
nUI_INFOPANEL_PALLYPOWER = "nUI_InfoPanel_PallyPower";

---------------------------------------------------
-- [v1.01.00] Some Constants
---------------------------------------------------

---------------------------------------------------
-- [v1.01.00] Set the Default values for the Infopanel
---------------------------------------------------
nUI_InfoPanels[nUI_INFOPANEL_PALLYPOWER ] =
{	
	enabled   = true,
	desc      = _L["Info Panel Text"],             -- player friendly name/description of the panel
	label     = _L["Info Panel Label"],	       -- label to use on the panel selection button face
	rotation  = nUI_INFOMODE_PALLYPOWER,            -- index or position this panel appears on/in when clicking the selector button
	full_size = true;                              -- this plugin requires the entire info panel port without the button bag
	
	options  =
	{
		enabled  = true,
	},
};

---------------------------------------------------
-- [v1.01.00] Set Plugin Values
---------------------------------------------------
local plugin    = CreateFrame( "Frame", nUI_INFOPANEL_PALLYPOWER, nUI_Dashboard.Anchor );
plugin.active   = true;

---------------------------------------------------
-- [v1.01.00] Validate Addon is loaded
---------------------------------------------------
local function onPallyPowerEvent()
	if event == "VARIABLES_LOADED" then		

		-- If the addon exists make sure they are loaded
		if not IsAddOnLoaded( "PallyPower" ) then 
			LoadAddOn( "PallyPower" );
		end
		
		-- If required addon is loaded and available then activate the plugin
		if ( IsAddOnLoaded( "PallyPower" ) ) then 
			plugin.active = true;
		else
			plugin.active = false;
		end
	end	
end
plugin:SetScript( "OnEvent", onPallyPowerEvent );
plugin:RegisterEvent( "VARIABLES_LOADED" );

---------------------------------------------------
-- [v1.01.00] Disable Decursive Frame
---------------------------------------------------
disablePallyPower = function()
	local PallyPower = plugin.PallyPower;
	if PallyPower.saved_parent then
		nUI_Movers:lockFrame( PallyPower, false, nil );
		PallyPower:SetParent( PallyPower.saved_parent );
		PallyPower:SetBackdropBorderColor( PallyPower.border_color );
		PallyPower:SetBackdropColor( PallyPower.backdrop_color );			
	end
end

---------------------------------------------------
-- [v1.01.00] Enable the Decursive Frame
---------------------------------------------------
enablePallyPower = function()
	local PallyPower = getglobal("PallyPowerFrame");
	plugin.PallyPower = PallyPower;
	
	-- Save some important information
	if not PallyPower.saved_parent then
		PallyPower.saved_parent   = PallyPower:GetParent();
		PallyPower.border_color   = PallyPower:GetBackdropBorderColor();
		PallyPower.backdrop_color = PallyPower:GetBackdropColor();		
	end
	
	-- Set the PallyPower Frame to fit into the info panel
	nUI_Movers:lockFrame( PallyPower, false, nil );
	PallyPower:SetParent( plugin.container );
	PallyPower:SetPoint( "TOPLEFT", plugin.container, "TOPLEFT", 10, -10 );
	PallyPower:SetPoint( "BOTTOM", plugin.container, "BOTTOM", 0, 0 );
	PallyPower:SetFrameStrata( plugin.container:GetFrameStrata() );
	PallyPower:SetFrameLevel( plugin.container:GetFrameLevel()+1 );
	PallyPower:SetBackdropBorderColor( 0, 0, 0, 0 );
	PallyPower:SetBackdropColor( 0, 0, 0, 0 );	
	--nUI_Movers:lockFrame( PallyPower, true, nil );

end


---------------------------------------------------
-- [v1.01.00] Resize the Decursive Frame
---------------------------------------------------
resizePallyPower = function(height,width)
	local PallyPower   = plugin.PallyPower;
	nUI_Movers:lockFrame( PallyPower, false, nil );
	PallyPower:SetWidth( width / 2 ); 
	PallyPower:SetHeight( height ); 
	--nUI_Movers:lockFrame( PallyPower, true, nil );
end

---------------------------------------------------
-- [v1.01.00] initPanel routine
---------------------------------------------------
plugin.initPanel = function( container, options )
	plugin.container = container;
	plugin.options   = options;
	if options and options.enabled then
		plugin.setEnabled( true );
	end
end

---------------------------------------------------
-- [v1.01.00] sizeChanged routine
---------------------------------------------------
plugin.sizeChanged = function( scale, height, width )
	local options  = plugin.options;
	plugin.scale = scale;
	
	resizePallyPower(height,width);
end	

---------------------------------------------------
-- [v1.01.00] Validate Enable Status
---------------------------------------------------
plugin.setEnabled = function( enabled )
	if plugin.enabled ~= enabled then
		plugin.enabled = enabled;
		if not enabled then
			disablePallyPower();
		else
			enablePallyPower();
		end				
	end			
end

---------------------------------------------------
-- [v1.01.00] setSelected routine
---------------------------------------------------
plugin.setSelected = function( selected )
	if selected ~= plugin.selected then
		plugin.selected = selected;
		if selected then
		else
		end
	end
end
